@@ -15,7 +15,7 @@ def setup_terrier(file_path):
         wget.download(url, file_path)
 
 file_path = os.path.dirname(os.path.abspath(__file__))
-print(file_path)
+# print(file_path)
 setup_terrier(file_path)
 import jnius_config
 jnius_config.add_classpath(os.path.join(file_path,"terrier-assemblies-5.1-jar-with-dependencies.jar"))
@@ -36,12 +36,12 @@ if __name__ == "__main__":
     # print(feat_res)
 
     retr = BatchRetrieve(index_path)
-    batch_retrieve_results=retr.transform(["light","dark"])
-    print(batch_retrieve_results)
+    batch_retrieve_results=retr.transform(topics)
+    # print(batch_retrieve_results)
 
     # retr.saveLastResult("dph.res")
     # retr.saveResult(batch_retrieve_results,"/home/alex/Documents/Pyterrier/result.res")
 
-    # qrels = Utils.parse_qrels("./vaswani_npl/qrels")
-    # eval = Utils.evaluate(batch_retrieve_results,qrels)
-    # print(eval)
+    qrels = Utils.parse_qrels("../vaswani_npl/qrels")
+    eval = Utils.evaluate(batch_retrieve_results,qrels)
+    print(eval)
