@@ -1,7 +1,8 @@
 import pandas as pd
 from jnius import autoclass, cast
-# import pytrec_eval
+import pytrec_eval
 import json
+import ast
 
 class Utils:
     @staticmethod
@@ -45,13 +46,16 @@ class Utils:
         res_dt = pd.DataFrame(dph_results,columns=['qid','docno','score'])
         return res_dt
 
-    # @staticmethod
-    # def evaluate(res,qrels):
-    #     batch_retrieve_results_dict = Utils.convert_df_to_pytrec_eval(res)
-    #     qrels_dic=Utils.convert_df_to_pytrec_eval(qrels, True)
-    #     evaluator = pytrec_eval.RelevanceEvaluator(qrels_dic, {'map', 'ndcg'})
-    #     return json.dumps(evaluator.evaluate(batch_retrieve_results_dict), indent=1)
-
+    @staticmethod
+    def evaluate(res,qrels, string=False):
+        batch_retrieve_results_dict = Utils.convert_df_to_pytrec_eval(res)
+        qrels_dic=Utils.convert_df_to_pytrec_eval(qrels, True)
+        evaluator = pytrec_eval.RelevanceEvaluator(qrels_dic, {'map', 'ndcg'})
+        result = evaluator.evaluate(batch_retrieve_results_dict)
+        if string:
+            return json.dumps(result, indent=1)
+        else:
+            return result
 
     # create a dataframe of string of queries or a list or tuple of strings of queries
     @staticmethod
